@@ -89,6 +89,7 @@ class Download(io.BytesIO):
         self._buff = bytearray(0)
         self._pos = 0
         self._seekable = True
+        self.content_length = -1
         super().__init__()
 
     def seek(self, offset, whence=0):
@@ -99,10 +100,18 @@ class Download(io.BytesIO):
         elif whence == 1:
             pos_seek = self._pos
         elif whence == 2:
-            pos_seek = 0
-        pos_seek += offset
-        if pos_seek != self._pos:
+            if self.content_length == -1:
+                # reset position to find end of file
+                # in case of we are at end of file...
+                self._pos = 0
+                self.__init_request()
+            pos_seek = self.content_length
 
+        pos_seek += offset
+        if pos_seek < 0:
+            raise OSError
+
+        if pos_seek != self._pos:
             if pos_seek > self._pos and \
                     (pos_seek - self._pos) < (10 * self._chunk_size):
                 read = 1
@@ -132,6 +141,9 @@ class Download(io.BytesIO):
         return self._seekable
 
     def __init_request(self):
+
+        pos_start = self._pos
+
         heads = None
         if self.__res is None or self._iter is None:
             if self._iter is not None:
@@ -140,18 +152,18 @@ class Download(io.BytesIO):
             self._buff = bytearray(0)
 
             if self._headers is not None:
-                start = self._pos + self._headers[0]
+                pos_start = pos_start + self._headers[0]
                 if len(self._headers) > 1:
-                    end = self._pos + self._headers[0] + self._headers[1]
+                    end = pos_start + self._headers[1]
                     heads = {
                         "range":
-                            f"bytes={start}"
+                            f"bytes={pos_start}"
                             f"-{end}"
                     }
                 else:
-                    heads = {"range": f"bytes={start}-"}
-            elif self._pos > 0:
-                heads = {"range": f"bytes={self._pos}-"}
+                    heads = {"range": f"bytes={pos_start}-"}
+            elif pos_start > 0:
+                heads = {"range": f"bytes={pos_start}-"}
             self.__res = get(
                 self._path,
                 self._auth,
@@ -159,6 +171,10 @@ class Download(io.BytesIO):
                 self._params
             )
             check_response(self.__res)
+            headers = self.__res.headers
+            for k, v in headers.items():
+                if k.lower() == 'content-length':
+                    self.content_length = int(v) + pos_start
 
     def getvalue(self) -> bytes:
         self.__init_request()
@@ -289,7 +305,12 @@ class DrbHttpNode(AbstractNode):
     @property
     def attributes(self) -> Dict[Tuple[str, str], Any]:
         self.__init_header()
-        return {(k, None): v for k, v in self._headers.items()}
+        attributes = {}
+        for k, v in self._headers.items():
+            if k.lower() == 'content-type':
+                k = 'Content-Type'
+            attributes[(k, None)] = v
+        return attributes
 
     def get_attribute(self, name: str, namespace_uri: str = None) -> Any:
         self.__init_header()
