@@ -5,5 +5,13 @@ class DrbHttpNodeException(DrbException):
     pass
 
 
+class DrbHttpAuthException(DrbException):
+    pass
+
+
+class DrbHttpServerException(DrbException):
+    pass
+
+
 class DrbHttpNodeFactoryException(DrbFactoryException):
     pass
